@@ -7,6 +7,17 @@
     :license: MIT, see LICENSE for more details.
 """
 
+import string
+from .charsets import change_charset
+
+B16_CHARS = string.hexdigits[0:16]
+
+def hexpad(x):
+    return ('0' * (len(x) % 2)) + x
+
+def charset_to_hex(s, original_charset):
+    return hexpad(change_charset(s, original_charset, B16_CHARS))
+
 def hex_to_int(s):
     try:
         return int(s, 16)
@@ -32,6 +43,14 @@ def is_hex(s):
         return True
 
 def is_int(i):
-    return isinstance(i, (int,long))
-
-
+    if isinstance(i, (int,long)):
+        return True
+    elif isinstance(i, str):
+        try:
+            int_i = int(i)
+        except:
+            return False
+        else:
+            return True
+    else:
+        return False
